Attribute VB_Name = "LCD2x16API"
'-------------------------------------------------------------------------------
Option Explicit
Option Language BasicX

' This is an API for the LCD2x16 display.

' CommandType
Private Const FormFeedCmd          As Byte = 12
Private Const ResetControllerCmd   As Byte = 14
Private Const SetGeometryCmd       As Byte = 15
Private Const SetTabSizeCmd        As Byte = 16
Private Const SetCursorPositionCmd As Byte = 17
Private Const SetContrastCmd       As Byte = 19
Private Const SetBacklightCmd      As Byte = 20
Private Const CommandEscapeCmd     As Byte = 21
Private Const RawDataEscapeCmd     As Byte = 23

' CursorStyle
Public Const HiddenCursor    As Byte = &HC
Public Const BlockCursor     As Byte = &HD
Public Const UnderlineCursor As Byte = &HE

Public Const MaxRow As Byte = 2
Public Const MaxColumn As Byte = 16
'-------------------------------------------------------------------------------
Public Sub LCDInitialize()

    Const LCDPowerupDelay As Single = 1.0
    Const InitialContrast As Byte = 20

    ' Allow internal LCD initialization. This is for a worst case condition,
    ' just after powering up the LCD.
    Call Delay(LCDPowerupDelay)

    ' Clear out pending I/O. The LCD is assumed to be in an undefined state,
    ' which means it may or may not be expecting characters.
    WaitForClearBuffer

    Call LCDPutByte(0)
    Call LCDPutByte(0)
    Call LCDPutByte(0)
    Call LCDPutByte(0)
    Call LCDPutByte(0)

    WaitForClearBuffer

    Call LCDPutByte(ResetControllerCmd)

    ' A reset takes about 1 s to complete.
    Delay 1.0

    ' Define the 2x16 geometry.
    Call LCDPutByte(SetGeometryCmd)
    Call LCDPutByte(16)
    Call LCDPutByte(&H80)
    Call LCDPutByte(&HC0)
    Call LCDPutByte(&H80)
    Call LCDPutByte(&H80)

    Call LCDClearScreen

    Call LCDPutContrast(InitialContrast)

    Call LCDPutBrightness(0)

End Sub
'-------------------------------------------------------------------------------
Public Sub LCDClearScreen()

    Call LCDPutByte(FormFeedCmd)

    WaitForClearBuffer

End Sub
'-------------------------------------------------------------------------------
Public Sub LCDMoveCursor( _
    ByVal Row As Byte, _
    ByVal Column As Byte)

    If (Row < 1) Then
        Row = 1
    ElseIf (Row > MaxRow) Then
        Row = MaxRow
    End If

    If (Column < 1) Then
        Column = 1
    ElseIf (Column > MaxColumn) Then
        Column = MaxColumn
    End If

    Call LCDPutByte(SetCursorPositionCmd)

    ' Note change from 1 base to 0 base.
    Call LCDPutByte(Row - 1)
    Call LCDPutByte(Column - 1)

End Sub
'-------------------------------------------------------------------------------
Public Sub LCDPutBrightness( _
    ByVal Value As Byte)

    Call LCDPutByte(SetBacklightCmd)

    Call LCDPutByte(Value)

End Sub
'-------------------------------------------------------------------------------
Public Sub LCDPutContrast( _
    ByVal Value As Byte)

    Call LCDPutByte(SetContrastCmd)

    Call LCDPutByte(Value)

End Sub
'-------------------------------------------------------------------------------
Public Sub LCDPutCursorStyle( _
    ByVal Value As Byte)

    Call LCDPutByte(CommandEscapeCmd)

    Call LCDPutByte(Value)

End Sub
'-------------------------------------------------------------------------------
Public Sub LCDDefineCustomCharacter( _
    ByVal CharacterNumber As Byte, _
    BitMap() As Byte)

' Allows characters 0 .. 7 to be defined as custom bitmaps. Each character
' is 8 pixels high and 5 pixels wide.
'
' BitMap is an 8 byte array. Element 1 of the array corresponds to the top
' row of pixels, element 2 is the next row down, and so forth. Pixel values
' are taken from the lower 5 bits of each byte. The upper 3 bits are ignored.

    Dim N As Byte
    Dim Address As Byte
    Const AddressOffset As Byte = &H40

    ' Check for legal character number.
    If (CharacterNumber < 0) Or (CharacterNumber > 7) Then
        Exit Sub
    End If

    ' Map the character to the internal address.
    Address = (CharacterNumber * 8) + AddressOffset

    Call LCDPutByte(CommandEscapeCmd)

    Call LCDPutByte(Address)

    For N = 1 To 8
        Call LCDPutByte(RawDataEscapeCmd)
        Call LCDPutByte(BitMap(N))
    Next

End Sub
'-------------------------------------------------------------------------------
Public Sub LCDPutTabSize( _
    ByVal Value As Byte)

    Select Case Value

        ' Only these values are legal.
        Case 1, 2, 4, 8

            ' Null

        Case Else

            ' If the value is illegal, do nothing.
            Exit Sub
    End Select

    ' The LCD expects an 8 bit negative number in two's complement format.
    ' Since we don't have 8 bit signed integers, we need to synthesize the
    ' internal bit pattern.
    Value = (Not Value) + 1

    Call LCDPutByte(SetTabSizeCmd)

    Call LCDPutByte(Value)

End Sub
'-------------------------------------------------------------------------------
Private Sub WaitForClearBuffer()

    ' We need a minimum of 2 ms.
    Delay 0.002

End Sub
'-------------------------------------------------------------------------------
