Attribute VB_Name = "LCD2x16brianDemo"
'-------------------------------------------------------------------------------
Option Explicit
Option Language BasicX
Option Pin26 zxOutputLow
' Serial port and pin definitions. These definitions depend on the BasicX
' system and serial ports being used, as well as the baud rate settings
' of the LCD.
Private Const SerialPort As Byte = 3
Private Const Baud       As Long = 9600
Private Const InputPin   As Byte = 5
Private Const OutputPin  As Byte = 5
'-------------------------------------------------------------------------------
Public Sub Main()

    Dim N As Byte
    Dim Percent As Byte
    Dim Brightness As Byte
    Dim Contrast As Byte
    Dim Row As Byte
    Dim Column As Byte
    Dim HexDigit As Byte

    Call LCDOpenSerialPort(SerialPort, Baud, InputPin, OutputPin)

    Call LCDInitialize

    Call LCDMoveCursor(1, 1)
    Call LCDPutStr("Demo of Brian's New Toy")
    Call Delay(2.0)
    Call LCDClearScreen
   
    '--------------------------------
    ' Display all character positions
    '--------------------------------

    For Column = 1 To MaxColumn

        If (Column < 10) Then
            HexDigit = Column + 48
        Else
            HexDigit = Column + 55
        End If

        Call LCDClearScreen

        For Row = 1 To MaxRow

            ' Test for odd-numbered row.
            If ((Row And 1) = 1) Then

                ' Odd rows -- character moves left to right.
                Call LCDMoveCursor(Row, Column)
                Call LCDPutByte(HexDigit)
            Else
                ' Even rows -- character moves right to left.
                Call LCDMoveCursor(Row, MaxColumn - Column + 1)
                Call LCDPutByte(HexDigit)
            End If
        Next

        Delay 0.3
    Next

    '----------------------
    ' Display cursor styles
    '----------------------

    Call LCDClearScreen
    Call LCDMoveCursor(1, 1)
    Call LCDPutStr("Block")
    Call LCDMoveCursor(2, 1)
    Call LCDPutStr("Cursor:")
    Call LCDPutCursorStyle(BlockCursor)
    Call Delay(2.0)

    Call LCDClearScreen
    Call LCDMoveCursor(1, 1)
    Call LCDPutStr("Underline")
    Call LCDMoveCursor(2, 1)
    Call LCDPutStr("Cursor:")
    Call LCDPutCursorStyle(UnderlineCursor)
    Call Delay(2.0)

    Call LCDClearScreen
    Call LCDMoveCursor(1, 1)
    Call LCDPutStr("Hidden")
    Call LCDMoveCursor(2, 1)
    Call LCDPutStr("Cursor:")
    Call LCDPutCursorStyle(HiddenCursor)
    Call Delay(2.0)

    '----------------------------
    ' Exercise brightness control
    '----------------------------

    Call LCDClearScreen
    For N = 0 To 10
        Percent = N * 10
        Brightness = CByte(CSng(Percent) * 2.5499)

        Call LCDClearScreen
        Call LCDMoveCursor(1, 1)
        Call LCDPutBrightness(Brightness)
        Call LCDPutStr("Backlight " & CStr(Percent) & " %")

        Call Delay(0.5)
    Next
    Call LCDPutBrightness(0)

    '--------------------------
    ' Exercise contrast control
    '--------------------------

    Call LCDClearScreen
    For N = 0 To 10
        Percent = N * 10
        Contrast = CByte(CSng(Percent) * 2.5499)

        Call LCDClearScreen
        Call LCDMoveCursor(1, 1)
        Call LCDPutContrast(Contrast)
        Call LCDPutStr("Contrast " & CStr(Percent) & " %")

        Call Delay(0.5)
    Next
    Call LCDPutContrast(0)

    '--------------
    ' Clock display
    '--------------

    Call LCDClearScreen
    Call PutTimestamp(2010, 05, 14, 12, 0, 0.0)
	Call LCDPutBrightness(35)	'inserted clock backlight

	Call RELAY 
    Call DisplayClock


End Sub
'-------------------------------------------------------------------------------
Private Sub DisplayClock()

    Dim T1 As Long
    Dim T2 As Long

    T1 = FixL(Timer)
	Do    
        Call LCDMoveCursor(1, 4)
        Call LCDPutStr(ToDate())

        ' Wait for time change.
        Do
            T2 = FixL(Timer)
        Loop Until (T1 <> T2)
        T1 = T2

        Call LCDMoveCursor(2, 5)
        Call LCDPutStr(ToTime())
	loop	  
End Sub
'-------------------------------------------------------------------------------
Public Function ToDate() As String

' Format:  "2010/06/14"  YEAR/MO/DA

    Dim Year As Integer
    Dim Month As Byte
    Dim Day As Byte

    Call GetDate(Year, Month, Day)

    ToDate = CStr(Year) & "/" _
        & TwoDigit(Month) & "/" _
        & TwoDigit(Day)& "  "
    Exit Function

End Function
'-------------------------------------------------------------------------------
Public Function ToTime() As String

' Format:  "15:29:35"

    Dim Hour As Byte
    Dim Minute As Byte
    Dim Second As Single

    Call GetTime(Hour, Minute, Second)

    ToTime = TwoDigit(Hour) & ":" _
        & TwoDigit(Minute) & ":" _
        & TwoDigit(CByte(Second))

End Function
'-------------------------------------------------------------------------------
Public Function TwoDigit( _
    ByVal Value As Byte) As String

' Outputs a 2-digit number with a leading 0. Valid range is 0 .. 99.

    Dim Tx As String * 2

    If (Value > 99) Then
        Tx = "**"
    Else
        If (Value < 10) Then
            Tx = "0" & CStr(Value)
        Else
            Tx = CStr(Value)
        End If
    End If

    TwoDigit = Tx

End Function
'-------------------------------------------------------------------------------
Private Sub RELAY()

	Const PinOne As Byte = 13 
	Const PinTwo As Byte = 10
	Const PinThree As Byte = 11
	Const PinFour As Byte = 12

	Const PinLow as Byte = 0 'Relay ON
	Const PinHigh as Byte =1 'Relay OFF

	
		Call PutPin(PinOne,PinLow)
		Call Delay(1.0)
		Call PutPin(PinOne, PinHigh)

		Call PutPin(PinTwo, PinLow)
		Call Delay(1.0)
		Call PutPin(PinTwo, PinHigh)

		Call PutPin(PinThree, PinLow)
		Call Delay(1.0)
		Call PutPin(PinThree, PinHigh)

		Call PutPin(PinFour, PinLow)
		Call Delay(1.0)
		Call PutPin(PinFour, PinHigh)

	
End Sub
	



