Attribute VB_Name = "LCDSerialPort"
'-------------------------------------------------------------------------------
Option Explicit
Option Language BasicX

' This is a driver for a serial port.

' Allocate space for 1 byte buffers, plus 9 bytes of overhead.
Private Const InputQueueSize As Integer = 10
Private Const OutputQueueSize As Integer = 10

Private InputQueue(1 To InputQueueSize) As Byte
Private OutputQueue(1 To OutputQueueSize) As Byte
'-------------------------------------------------------------------------------
Public Sub LCDOpenSerialPort( _
    ByVal Port As Byte, _
    ByVal Baud As Long, _
    ByVal InputPin As Byte, _
    ByVal OutputPin As Byte)

' Opens a serial port with the specified baud rate and pin numbers.

    ' Check port number.
    If (Port < 1) Or (Port > 3) Then
        Exit Sub
    End If

    Call OpenQueue(OutputQueue, OutputQueueSize)

    Call OpenQueue(InputQueue, InputQueueSize)

    ' Use inverted logic, no parity, 8 data bits.
    If (Port = 3) Then
        Call DefineCom3(InputPin, OutputPin, bx1000_1000)
    End If

    Call OpenCom(Port, Baud, InputQueue, OutputQueue)

End Sub
'-------------------------------------------------------------------------------
Public Sub LCDGetByte( _
    ByRef Value As Byte, _
    ByRef Success As Boolean)

' Inputs a byte from the serial port, if available. Returns regardless.  The
' Success flag is set depending on whether a byte is available.

    ' Find out if anything is in the queue.
    Success = StatusQueue(InputQueue)

    ' If data is in the queue, extract it.
    If (Success) Then
        Call GetQueue(InputQueue, Value, 1)
    Else
        Value = 0
    End If

End Sub
'-------------------------------------------------------------------------------
Public Sub LCDPutStr( _
    ByVal Tx As String)

    Dim N As Integer
    Dim C As String * 1
    Dim B As Byte

    For N = 1 To Len(Tx)
        C = Mid(Tx, N, 1)
        B = Asc(C)
        Call LCDPutByte(B)
    Next

End Sub
'-------------------------------------------------------------------------------
Public Sub LCDPutByte( _
    ByVal Value As Byte)

    Call PutQueue(OutputQueue, Value, 1)

End Sub
'-------------------------------------------------------------------------------
